@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: fix_template.py 9978 2017-05-20 15:24:37Z Lavender $
+# $Id: fix_template.py 9979 2017-05-20 16:33:56Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-05-20 23:24:37 +0800 (週六, 20 五月 2017) $
-# $Revision: 9978 $
+# $Date: 2017-05-21 00:33:56 +0800 (週日, 21 五月 2017) $
+# $Revision: 9979 $
 
 import os
 import logging
@@ -76,7 +76,7 @@ class Command(BaseCommand):
                 fileName = file
             else:
                 index = file.index('.html')
-                fileName = file[:index] + 'Fix.html'
+                fileName = file[:index] + '_user.html'
                 
            
             with open(fileName, 'w') as f:
