@@ -57,7 +57,7 @@ class BuildBoilerplateTest(unittest.TestCase):
         
                 
         os.system(
-            "%s manage.py build_boilerplate %s" % (sys.executable, 
+            "%s Manage.py build_boilerplate %s" % (sys.executable, 
                                                    dst))
 
         with open(answer, 'r') as f:
@@ -119,8 +119,8 @@ class BuildBoilerplateTest(unittest.TestCase):
         self.runBuildBoilerplate('Attr.html', 'AttrAnswer.html', 
                                  dst=TEMPLATES_DIR_PATH, delete=False, 
                                  rename='index.html')
-        os.system("%s manage.py create_pages" % sys.executable)
-        os.system("%s manage.py pluginize" % sys.executable)
+        os.system("%s Manage.py create_pages" % sys.executable)
+        os.system("%s Manage.py pluginize" % sys.executable)
 
         with open(
             os.path.join(STATIC_DIT_PATH, 'js', 'FixTemplate.js'), 'r') as f:
